# API Reference

## Classes

```{eval-rst}
.. currentmodule:: sciline

.. autosummary::
   :toctree: ../generated/classes
   :template: class-template.rst
   :recursive:

   ParamTable
   Pipeline
   Scope
   Series
   scheduler.Scheduler
   scheduler.DaskScheduler
   scheduler.NaiveScheduler
   task_graph.TaskGraph
```

## Exceptions

```{eval-rst}
.. autosummary::
   :toctree: ../generated/classes
   :template: class-template.rst
   :recursive:

   AmbiguousProvider
   UnboundTypeVar
   UnsatisfiedRequirement
```

## Submodules

```{eval-rst}
.. autosummary::
   :toctree: ../generated/modules
   :template: module-template.rst
   :recursive:

   sphinxext
```